/*! @file application_defs.h
 * @brief This file contains hardware specific definitions defined by the application.
 *
 * @b COPYRIGHT
 * @n Silicon Laboratories Confidential
 * @n Copyright 2012 Silicon Laboratories, Inc.
 * @n http://www.silabs.com
 */

#ifndef APPLICATION_DEFS_H_
#define APPLICATION_DEFS_H_

#define lSys_SysClockFreq_c (24500000.0)
#define lSys_RadioCrystalFreq_c (30000000.0)
#define wTmr_Tmr3Divider_c (1.0)        //(12.0)
#define PAYLOAD_BYTE_LENGTH_MAX         (9)
//-------------------------------------------------------
//Settings for Si4356 configured for OOK 0.5 - 5 kbps
//SEL2=GND, SEL3=GND
//and MCU configured for Holtek packet 2141baud
//SW1/1=ON, SW1/2=ON
// symbol rate of the received data (baud)
#define DATARATE1			(2141)			
//Received data sampling clock rate in Hz, integer multiple of symbolrate
#define wTmr_Tmr3DesiredFreq1_c         (29974.0)
#define lTmr_Tmr3CntMax1_c              (lSys_SysClockFreq_c / wTmr_Tmr3Divider_c / wTmr_Tmr3DesiredFreq1_c)
// size of the glitch filtering window in bits (max 16)
#define WINDOWSIZE1			(10)
//sync word pattern max 4 bytes
#define SYNCWORD1			(0x000049)      //pilot period, start bit and two MSb of address are used as sync			
#define NOISEMASK_1                     (0xffffed)      //middle of two address bits are masked 
//length of the sync word in bits, max 32
#define SYNCWORD_BIT_LENGTH1		(24)				
#define PAYLOAD_BYTE_LENGTH_1		(3)	// length of HT6P20 packet payload	
#define MANCHESTER_USED_1               FALSE
#define NORMALPACKET_1                  FALSE
//-----------------------------------------------------------
//Settings for Si4356 configured for OOK 10 - 50 kbps
//SEL2=OUT1, SEL3=GND
//and MCU configured for normal packet 9600baud manchester
//SW1/1=ON, SW1/2=OFF
// symbol rate of the received data (baud)
#define DATARATE2			(9600)
//Received data sampling clock rate in Hz, integer multiple of symbolrate
#define wTmr_Tmr3DesiredFreq2_c         (96000)//(124800.0)
#define lTmr_Tmr3CntMax2_c              (lSys_SysClockFreq_c / wTmr_Tmr3Divider_c / wTmr_Tmr3DesiredFreq2_c)
// size of the glitch filtering window in bits (max 16)
#define WINDOWSIZE2			(9)//(16)			// size of the glitch filtering window
// calculated parameters
// do not change
//#define SYNCWORD2		        0x2dd4			//sync word pattern max 4 bytes, or max 2byte if manchester used
#define SYNCWORD2                       (0xa659599a)             //define manchester encoded form
#define NOISEMASK_2                     (0xffffffff)
#define SYNCWORD_BIT_LENGTH2		(32)			//length of the sync word in bits, max 32
#define PAYLOAD_BYTE_LENGTH_2		(9)                     // length of normal packet payload	
#define MANCHESTER_USED_2               TRUE
#define NORMALPACKET_2                  TRUE
//-------------------------------------------------------------
//Settings for Si4356 configured for GFSK 0.5 - 30 kbps
//SEL2=OUT1, SEL3=OUT1
//and MCU configured for normal packet 9600baud NRZ
//SW1/1=OFF, SW1/2=OFF
#define lTmr_Tmr3DesiredFreq3_c         (96000.0)
#define lTmr_Tmr3CntMax3_c              (lSys_SysClockFreq_c / wTmr_Tmr3Divider_c / lTmr_Tmr3DesiredFreq3_c)
// symbol rate of the received data (baud)
#define DATARATE3		        (9600)
// size of the glitch filtering window in bits (max 16)
#define WINDOWSIZE3			(9)
//sync word pattern max 4 bytes
#define SYNCWORD3			(0x2dd4)			
#define NOISEMASK_3                     (0xffff)
//length of the sync word in bits, max 32
#define SYNCWORD_BIT_LENGTH3		16				
// length of normal packet payload
#define PAYLOAD_BYTE_LENGTH_3	        (9)                      	
#define MANCHESTER_USED_3               FALSE
#define NORMALPACKET_3                  TRUE
//--------------------------------------------------------------

#endif /* APPLICATION_DEFS_H_ */
