/*
** ============================================================================
**
** FILE
**  retime_phandler.c
**
** DESCRIPTION
**  Rrealize the retime and packethandler functions
**
** CREATED
**  Silicon Laboratories Hungary Ltd
**
** COPYRIGHT
**  Copyright 2010 Silicon Laboratories, Inc.  
**	http://www.silabs.com
**
** ===========================================================================*/

#include "..\drivers\bsp.h"
#include "deglitch_retime.h"
#include "phandler.h"


                /* ======================================= *
                 *  		G L O B A L  V A R I A B L E  	  *
                 * ======================================= */

bit fSyncWordFound;								
bit fPacketReceived; 							
U8 PayloadBuffer[PAYLOAD_BYTE_LENGTH_MAX];
U32 lSyncWordMask;
U32 lNoiseMask;
U32 lSyncWord;	
U8 bPayloadLength;
bit fManchesterUsed;
bit fNormalPacket;
bit fOddBit;
bit fMiddleBit;


void PhandlerInit()
{
        U8 i;
	fSyncWordFound = FALSE;								
	fPacketReceived = FALSE;
	for ( i = 0; i < bPayloadLength; i++ )
        {
		PayloadBuffer[i] = 0;
        }
}

/*+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
  +
  + FUNCTION NAME:	void PacketHandler()
  +
  + DESCRIPTION:    	This function process the retimed data, finds the sync word, checks the CRC and gives back the payload
  +
  + INPUT:			 	bRetimedBitBuffer - the retimed bits (8)
  +				
  +
  + OUTPUT:                             PayloadBuffer - the payload bytes
  +                                     fPacketReceived - flag indicating packet reception
  +
  + NOTES:          the process starts always with the MSB bit
  +
  +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/ 

void PacketHandler()
{
	U8 i;
	static U8 TempByte,BitCnt, ByteCnt;
	static U32 lSyncWordTempByte;

	i = 0;

	while(i< 8)
	{


		if ( !fSyncWordFound )	//if the sync word hasn't been found yet
		//check for synch word
		{
		
			//save bits into bytes
			lSyncWordTempByte <<= 1;
			lSyncWordTempByte &= lSyncWordMask;
                        if ( bRetimedBitBuffer & 0x80 )
			{
				lSyncWordTempByte |= 0x00000001;
			}
                        bRetimedBitBuffer <<= 1;
			if((lSyncWordTempByte & lNoiseMask) == lSyncWord)
			{//synchron word found

				fSyncWordFound = TRUE;
				BitCnt = 0;
				ByteCnt = 0;
                                fOddBit = TRUE;
                                fMiddleBit = FALSE; 

			}
		}
		else    //decode payload
		{
                        if (fNormalPacket)
                        {
                                if (fOddBit && fManchesterUsed) //do not store odd bits of manchester encoded payload
                                { 
                                        fOddBit = FALSE;
                                        bRetimedBitBuffer <<= 1;  
                                }
                                else
                                {
                                        fOddBit = TRUE;  
			                //save bits into bytes
			                TempByte <<= 1;
                                        if (bRetimedBitBuffer & 0x80)
			                {
				                TempByte |= 0x01;
			                }
                                        bRetimedBitBuffer <<= 1;
			                if( ++BitCnt == 8 )
			                {//save the next byte into the buffer
				                PayloadBuffer[ByteCnt++] = TempByte;
				                BitCnt = 0;
				                //check whether the number of specified bytes already received
				                if(ByteCnt == bPayloadLength)   //packet is received
				                {
					                fSyncWordFound = FALSE;
                                                        //Check received CRC
                                                        if (*(U16*)&PayloadBuffer[bPayloadLength - 2] == vCalculateCrc() )
                                                        {
					                        fPacketReceived = TRUE;
                                                                //use only lower 20 bits of the transmitter ID
                                                                (*(U32*)&PayloadBuffer[0]) &= 0x000fffff;
                                                                //mask button bits in status byte
                                                                PayloadBuffer[4] &= 0x1f;
					                        //LED2=1;
                                                        }
				                }
                                        }				
			        }
                        }
                        else //Holtek packet
                        {
                                
                                if (fOddBit)    //check if first bit of triplet is zero, but do not store
                                {
                                        if ( bRetimedBitBuffer & 0x80 )
                                        {       //bit error, go back to sync search
				                fSyncWordFound = FALSE;
                                        }
                                        bRetimedBitBuffer <<= 1;
                                        fOddBit = FALSE;
                                        fMiddleBit = TRUE;      
                                }
                                else if (fMiddleBit)
                                {
                                        //invert and save middle bits of triplets into bytes
			                TempByte <<= 1;
                                        if (!(bRetimedBitBuffer & 0x80))
			                {
				                TempByte |= 0x01;
			                }
                                        bRetimedBitBuffer <<= 1;
		                        if( ++BitCnt == 8 )
			                {//save the next byte into the payload buffer
				                PayloadBuffer[ByteCnt++] = TempByte;
				                BitCnt = 0;
				                //check whether the number of specified bytes already received or not
				                if(ByteCnt == bPayloadLength)
				                {       //packet is received
				                        fSyncWordFound = FALSE;
					                fPacketReceived = TRUE;
                                                        //move button information to be compatible with normal packet
                                                        PayloadBuffer[4] = PayloadBuffer[2] & 0x0f;
                                                        //move transmitter ID to be compatible with normal packet
                                                        (*(U32*)&PayloadBuffer[0]) >>= 12;
                                                }
				        }
                                        fMiddleBit = FALSE;
                                }
                                else    //check if third bit of triplet is one, but do not store
                                {
                                        if (!(bRetimedBitBuffer & 0x80))
			                {       //bit error, go back to sync search
				                fSyncWordFound = FALSE;
			                }
                                        bRetimedBitBuffer <<= 1;
                                        fOddBit = TRUE;
                                }
                        }
		}
		i++;
	}
}

/*+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
  +
  + FUNCTION NAME:	void vCalculateCrc(void)
  +
  + DESCRIPTION:    	This function calculates the crc of the received payload
  +
  + INPUT:		PayloadBuffer - the received payload bytes 
  +			bPayloadLength - number of the payload bytes
  +
  + RETURN:       
  +
  + NOTES:          
  +
  +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/ 
//Bit pattern used (1)1000 0000 0000 0101, X16+X15+X2+1
U16 vCalculateCrc(void)
{
        U8 i,j;
        U16 wCrc;
        wCrc = 0xffff;
        for(j = 0;j<(bPayloadLength - 2);j++)
        {
                wCrc = wCrc ^ ((U16)PayloadBuffer[j]<<8);

                for (i = 8; i != 0; i--)
                {
                        if (wCrc & 0x8000)
                        {
	                        wCrc = (wCrc << 1) ^ 0x8005;
                        }
                        else
	                {
                                wCrc <<= 1;
                        }
                }
        }
  return wCrc;
}
