/*! @file radio.c
 * @brief This file contains functions to 
 *
 * @b COPYRIGHT
 * @n Silicon Laboratories Confidential
 * @n Copyright 2012 Silicon Laboratories, Inc.
 * @n http://www.silabs.com
 */

#include "..\drivers\bsp.h"

/*****************************************************************************
 *  Local Macros & Definitions
 *****************************************************************************/

/*****************************************************************************
 *  Global Variables
 *****************************************************************************/

/*****************************************************************************
 *  Local Function Declarations
 *****************************************************************************/



/*! Error hook */
#define ERROR_HOOK              while (TRUE) 				                \
                                { 						        \
					SEGMENT_VARIABLE(wDelay, U16, SEG_XDATA);       \
					for (; wDelay--;) ;				\
                                        LED4 = !LED4; 	  				\
                                }

/*!
 * Initialize the Si4356 radio.
 *
 * @param[in] none.
 *
 * @return    none.
 *
 * @note
 *
 */
void vRadio_Init(void)
{
	vRadio_PowerUp();
	
}

/*!
 * Power Up the Si4356 radio.
 *
 * @param[in] none.
 *
 * @return    none.
 *
 * @note
 *
 */
void vRadio_PowerUp(void)
{
	SEGMENT_VARIABLE(wDelay, U16, SEG_XDATA);
	
	MCU_STBY = 1;
        MCU_SDN = 1;
	
	for(wDelay=0x07FF; wDelay--;)
        {
                //wait
        } 

        MCU_SDN = 0;
	
}

/*!
 * Wake Up the Si4356 radio.
 *
 * @param[in] none.
 *
 * @return    none.
 *
 * @note
 *
 */
void vRadio_WakeUp(void)
{
	// If the radio is in sleep mode
	if(MCU_OUT0 == 1)
	{	
		//	Force the radio to awake mode
		vRadio_ActivateImpulse();
	}
}


/*!
 * Putthe Si4356 radio to sleep mode.
 *
 * @param[in] none.
 *
 * @return    none.
 *
 * @note
 *
 */
void vRadio_Sleep(void)
{	
	// If the radio is awake
	if(MCU_OUT0 == 0)
	{	
		// Force the radio to sleep mode
		vRadio_ActivateImpulse();
	}

}

/*!
 * Send an impulse to the Si4356 radio .
 *
 * @param[in] none.
 *
 * @return    none.
 *
 * @note
 *
 */
void vRadio_ActivateImpulse(void)
{
	SEGMENT_VARIABLE(wDelay, U16, SEG_XDATA) = 0x0FFF;
	
	// Send a wake up impulse to the radio
 	MCU_STBY = 0;

	for(; wDelay--;)
        {
                //wait
        }
		
	MCU_STBY = 1;

	// LED1 blinks once
	vHmi_ChangeLedState(eHmi_Led1_c, eHmi_LedBlinkOnce_c);
}






