/*! @file sample_code_func.c
 * @brief This file contains functions to manage behavior of basic human module interfaces (push-buttons, switches, LEDs).
 *
 * @b COPYRIGHT
 * @n Silicon Laboratories Confidential
 * @n Copyright 2012 Silicon Laboratories, Inc.
 * @n http://www.silabs.com
 */

#include "..\drivers\bsp.h"


/*------------------------------------------------------------------------*/
/*                          Global variables                              */
/*------------------------------------------------------------------------*/
U32 xdata lAssociatedID;
bit fAssociate;
/*------------------------------------------------------------------------*/
/*                          Function implementations                      */
/*------------------------------------------------------------------------*/

/*!
 * This function is used to check if an ID is associated to the receiver.
 *
 * @return  None.
 */
BIT gIdIsAssociated(U32 lReceivedId)
{
        if (lReceivedId == lAssociatedID)
        {
                return TRUE;
        }
        else
        {
                return FALSE;
        }
}

/*!
 * This function is used to push the radio to sleep or awake state.
 *
 * @return  None.
 */

void vSampleCode_ModeChanging(void)
{
        SEGMENT_VARIABLE(boPbPushTrack, U8, SEG_XDATA);
        SEGMENT_VARIABLE(woPbPushTime, U16, SEG_XDATA);

  	gHmi_PbIsPushed(&boPbPushTrack, &woPbPushTime);

  	// If button 1 was pushed
  	if(boPbPushTrack & eHmi_Pb1_c)
  	{ // activate association mode
  	        fAssociate = TRUE;
                vHmi_ClearAllLeds();
                vHmi_ChangeLedState(eHmi_Led2_c, eHmi_LedOn_c);
                vHmi_ChangeLedState(eHmi_Led3_c, eHmi_LedOn_c);
                vHmi_ChangeLedState(eHmi_Led1_c, eHmi_LedBlink2Hz_c);
                vHmi_ChangeLedState(eHmi_Led2_c, eHmi_LedBlink2Hz_c);
                vHmi_ChangeLedState(eHmi_Led3_c, eHmi_LedBlink2Hz_c);
                vHmi_ChangeLedState(eHmi_Led4_c, eHmi_LedBlink2Hz_c);
        }
  	   
	// If button 2 was pushed
  	if(boPbPushTrack & eHmi_Pb3_c)
  	{
  	        //Stop association mode
                fAssociate = FALSE;
                vHmi_ChangeLedState(eHmi_Led2_c, eHmi_LedOff_c);
                vHmi_ChangeLedState(eHmi_Led3_c, eHmi_LedOff_c);
                vHmi_ChangeLedState(eHmi_Led4_c, eHmi_LedOff_c);
                vHmi_ChangeLedState(eHmi_Led1_c, eHmi_LedOn_c);
  	}

}



