/*! @file isr.c
 * @brief Header file of menu handler driver.
 *
 * @b COPYRIGHT
 * @n Silicon Laboratories Confidential
 * @n Copyright 2012 Silicon Laboratories, Inc.
 * @n http://www.silabs.com
 */

#ifndef MENU_H_
#define MENU_H_


/*------------------------------------------------------------------------*/
/*                          Global definitions                            */
/*------------------------------------------------------------------------*/


/*------------------------------------------------------------------------*/
/*          Global structure & enumeration definitions                    */
/*------------------------------------------------------------------------*/

/*!
 * @brief This structure contains next state information of the menu state.
 */
typedef struct _tMnu_MenuNextState
{
    U8 bMenuState;      /**< Actual menu state */
    U8 bInput;          /**< Input stimuli that causes menu to change to next state */
    U8 bMenuNextState;  /**< Next menu state caused by input */
} tMnu_MenuNextState;

/*!
 * @brief This structure contains information of the menu state.
 */
typedef struct _tMnu_MenuState
{
    U8 bMenuState; /**< Actual menu state */
    U8 (*pStateFunction)(U8 biInput); /**< Handler function of the menu state */
} tMnu_MenuState;

/*!
 * @brief This structure contains operation information of the current and next menu state.
 */
typedef struct _tMnu_MenuStateInfo
{
    U8 bMenuState;      /**< Actual menu state */
    U8 bInput;          /**< Input stimuli that causes menu to change to next state */
    U8 bMenuNextState;  /**< Next menu state caused by input */
    U8 (*pbStateFunction)(U8 biInput); /**< Handler function of the menu state */
} tMnu_MenuStateInfo;


/*------------------------------------------------------------------------*/
/*                           Function prototypes                          */
/*------------------------------------------------------------------------*/

void  vMnu_InitMenu(tMnu_MenuState *pariAppMenuState, tMnu_MenuNextState *pariAppMenuNextState, U8 (*pbiAppMnuSwStateHandler)(void));
void  vMnu_MenuHandler(void);
void  vMnu_MenuChangeState(U8 biNewMenuState);
U8    bMnu_MenuButtonStep(U8 biMenuState, U8 biInput);
void  vMnu_DeleteMenuFunction(void);
U8    bMnu_GetMenuState(void);


#endif /* MENU_H_ */

